@@ -23,23 +23,14 @@ tabItem <- tab_item
 #' Create a panel with tabs.
 #' @description Create a panel with tabs.
 #' @param ... Tabs.
-#' @param  selected Which tab should be active on start.
 #' @return A panel with tabs that can be passed to \code{\link[semantic.dashboard]{dashboardBody}}
 #' @export
 #' @examples
 #' tabItems(
 #'  tabItem(tabName = "tab1", "Tab 1"),
 #'  tabItem(tabName = "tab2", "Tab 2"))
-tab_items <- function(..., selected = 1){
-  tabs <- list(...)
-  if (round(selected) < 1 | round(selected) > length(tabs) | !is.numeric(selected)){
-    warning("Wrong tabItem selected, switched to first one!")
-    selected_tab <- 1
-  } else {
-    selected_tab <- selected
-  }
-  tabs[[selected_tab]]$attribs$class <- paste(tabs[[selected_tab]]$attribs$class, "active")
-  shiny::tags$div(class = "tab-content", tabs)
+tab_items <- function(...){
+  shiny::tags$div(class = "tab-content", list(...))
 }
 
 #' @describeIn tab_items Create a panel with tabs (alias for \code{tab_items} for compatibility with \code{shinydashboard})
